@@ -47,7 +47,7 @@ setMethod("nrm", signature(x="irt.pars", cat="ANY"), function(x, cat, theta, dim
 			tmp <- sep.pars(x@pars[[i]], x@cat[[i]], x@poly.mod[[i]], dimensions=x@dimensions[i], ...)
 			out[[i]] <- nrm(tmp, ...)
 		}
-		names(out) <- paste("Group",1:x@groups,sep="")
+		names(out) <- names(x@pars)
 		return(out)
 	} else {
 		x <- sep.pars(x@pars, x@cat, x@poly.mod, dimensions=x@dimensions, ...)
